==> sliding_panel-1.0.4.tar.gz: README.md <==
# sliding_panel

A Flutter slidable widget that provides an easy to use configuration. Just as you want it!


<br>

<img width="300px" alt="Demo" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/demo.gif?token=AKZ72JQWCJZZVCOAWSSKAI25ULZ6M"/>

<br><br>

Make choices | Customize it | Get full control
--- | --- | ---
<img width="256px" alt="Screenshot" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/screen1.png?token=AKZ72JS2NLZMIK2RNDILOWC5ULZ6S"/> | <img width="256px" alt="Screenshot" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/screen2.png?token=AKZ72JRZZV3LYF2TRDI2YHK5ULZ6W"/> | <img width="256px" alt="Screenshot" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/screen3.png?token=AKZ72JXACM7LBRSAY6JSGZ25ULZ62"/>

#### Easily put your content in the panel, customize it and then just use the panel for various purposes like, 
- Showing some persistent content on bottom of the screen.
- Can be used like `showModalBottomSheet()` from Flutter to make user choices.
- Also use like `DraggableScrollableSheet()` and put scrollable content inside the panel.

## :point_right: How to use sliding_panel:
Please visit the [**Wiki**](https://github.com/RaviKavaiya/sliding_panel/wiki) to see how you can get this working.

### :ok_hand: Liked my work?
You can always hit the :+1: button and :star: it. 

**Still not enough??? [paypal.me](https://www.paypal.me/ravikavaiya).** 

<br>

### Users of `v0.5.0` and `0.7.0`:
The latest stable release (`v1.0.1`) has landed with many improvements. There are some breaking changes, too. For that, visit the [**Migration guide**](https://github.com/RaviKavaiya/sliding_panel/wiki/Migration-guide).

<br>

### A note for `v0.2.0` and `v0.1.0` users :worried:
From version 0.5.0, we have a LOADS of breaking :boom: changes, which means that simply updating the package won't give you all the bells and whistles of new version. :pensive: For updating guide, please go to the [**Migration guide**](https://github.com/RaviKavaiya/sliding_panel/wiki/Migration-guide).
- After following this guide, you will enjoy new features.

==> sliding_panel-1.2.3.tar.gz: README.md <==
# sliding_panel

The most customisable bottom sliding panel you can find on [**pub.dev**](https://pub.dev/packages/sliding_panel). Just as you want it!


<br>

Features you would love
---
<img width="300px" alt="Demo" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/anim_demo.gif"/>

<br><br>

Take control | Customize the way you want | Various purposes
--- | --- | ---
<img width="256px" alt="Screenshot" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/customization.png"/> | <img width="256px" alt="Screenshot" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/gradients.png"/> | <img width="256px" alt="Screenshot" src="https://raw.githubusercontent.com/RaviKavaiya/sliding_panel/master/demo/modal.png"/>

#### Easily put your content in the panel, customize it and then just use the panel for various purposes like, 
- Showing some persistent content on bottom of the screen.
- Can be used like `showModalBottomSheet()` from Flutter to make user choices.
- Also use like `DraggableScrollableSheet()` and put scrollable content inside the panel.

## :point_right: How to use sliding_panel:
Please visit the [**Wiki**](https://github.com/RaviKavaiya/sliding_panel/wiki) to see how you can get this working.

### :ok_hand: Liked my work?
You can always hit the :+1: button and :star: it. 

**Still not enough??? [paypal.me](https://www.paypal.me/ravikavaiya).** 

<br>

### Users of `v0.5.0` and `0.7.0`:
The latest stable release (`v1.0.1`) has landed with many improvements. There are some breaking changes, too. For that, visit the [**Migration guide**](https://github.com/RaviKavaiya/sliding_panel/wiki/Migration-guide).

<br>

### A note for `v0.2.0` and `v0.1.0` users :worried:
From version 0.5.0, we have a LOADS of breaking :boom: changes, which means that simply updating the package won't give you all the bells and whistles of new version. :pensive: For updating guide, please go to the [**Migration guide**](https://github.com/RaviKavaiya/sliding_panel/wiki/Migration-guide).
- After following this guide, you will enjoy new features.
